@@ -1,24 +1,25 @@
 from django.test import TestCase
 
-from djangocms_bootstrap4.constants import (
-    ALIGN_CHOICES, COLOR_STYLE_CHOICES, DEVICE_CHOICES, DEVICE_SIZES, TAG_CHOICES,
+from djangocms_bootstrap5.constants import (
+    ALIGN_CHOICES, COLOR_STYLE_CHOICES, DEVICE_CHOICES, DEVICE_SIZES,
+    TAG_CHOICES,
 )
 
 
-class B4ConstantsTestCase(TestCase):
+class B5ConstantsTestCase(TestCase):
     # make sure to update the documentation
     # when changing any values in these
 
     def test_constants(self):
-        self.assertEqual(DEVICE_CHOICES, (
+        self.assertEquals(DEVICE_CHOICES, (
             ('xs', 'Extra small'),   # default <576px
             ('sm', 'Small'),         # default ≥576px
             ('md', 'Medium'),        # default ≥768px
             ('lg', 'Large'),         # default ≥992px
             ('xl', 'Extra large'),   # default ≥1200px
         ))
-        self.assertEqual(DEVICE_SIZES, ('xs', 'sm', 'md', 'lg', 'xl'))
-        self.assertEqual(TAG_CHOICES, (
+        self.assertEquals(DEVICE_SIZES, ('xs', 'sm', 'md', 'lg', 'xl'))
+        self.assertEquals(TAG_CHOICES, (
             ('div', 'div'),
             ('section', 'section'),
             ('article', 'article'),
@@ -26,7 +27,7 @@ class B4ConstantsTestCase(TestCase):
             ('footer', 'footer'),
             ('aside', 'aside')
         ))
-        self.assertEqual(COLOR_STYLE_CHOICES, (
+        self.assertEquals(COLOR_STYLE_CHOICES, (
             ('primary', 'Primary'),
             ('secondary', 'Secondary'),
             ('success', 'Success'),
@@ -36,7 +37,7 @@ class B4ConstantsTestCase(TestCase):
             ('light', 'Light'),
             ('dark', 'Dark'),
         ))
-        self.assertEqual(ALIGN_CHOICES, (
+        self.assertEquals(ALIGN_CHOICES, (
             ('text-left', 'Left'),
             ('text-center', 'Center'),
             ('text-right', 'Right'),
